pub fn canonical_message(endpoint: SuotarEndpoint, code: &str) -> StringExpand description
sisuTemporarilyUnavailable is worded differently per endpoint, reproduced here so a client
keying off message instead of code breaks.
pub fn canonical_message(endpoint: SuotarEndpoint, code: &str) -> StringsisuTemporarilyUnavailable is worded differently per endpoint, reproduced here so a client
keying off message instead of code breaks.